@@ -18,6 +18,7 @@ import pypatterns.filter as FilterModule
 
 import pomsets.command as TaskCommandModule
 import pomsets.definition as DefinitionModule
+import pomsets.error as ErrorModule
 import pomsets.library as DefinitionLibraryModule
 import pomsets.parameter as ParameterModule
 import pomsets.task as TaskModule
@@ -43,6 +44,7 @@ def createEchoDefinition():
         parameterOrderings = None,
         executable = executable
     )
+    definition.name('echo')
     return definition
 
 DEFINITION_ECHO = createEchoDefinition()
@@ -58,7 +60,9 @@ class BaseTestClass(object):
 
     def setUp(self):
         automaton = AutomatonModule.Automaton()
-        automaton.setThreadPool(None, CloudModule.Pool(1))
+        automaton.setThreadPool(
+            None, 
+            CloudModule.Pool(self.getNumWorkersToInstantiate()))
         automaton.commandManager(CommandPatternModule.CommandManager())
         self.automaton = automaton
         return
@@ -66,6 +70,9 @@ class BaseTestClass(object):
     def tearDown(self):
         return
 
+    def getNumWorkersToInstantiate(self):
+        return 1
+
     def createCommandBuilderMap(self):
         commandBuilder = TaskCommandModule.CommandBuilder(
             TaskCommandModule.buildCommandFunction_commandlineArgs
@@ -108,6 +115,7 @@ class BaseTestClass(object):
         requestContext = self.getRequestContext(
             task=task, executeEnvironment=executeEnvironment
         )
+
         request = threadpool.WorkRequest(
             executeTaskFunction,
             args = [],
@@ -115,6 +123,7 @@ class BaseTestClass(object):
             callback = successCallback,
             exc_callback = errorCallback
         )
+
         threadPool = automaton.getThreadPoolUsingRequest(request)
         request.kwds['thread pool'] = threadPool
         
@@ -238,7 +247,8 @@ class TestCase4(BaseTestClass, unittest.TestCase):
         
         node = compositeDefinition.createNode(id='node')
         node.definitionToReference(atomicDefinition)
-        
+        node.name('echo')
+
         compositeDefinition.connectParameters(
             compositeDefinition, 'item to echo',
             node, 'item to echo'
@@ -287,6 +297,7 @@ class TestCase8(BaseTestClass, unittest.TestCase):
                 compositeDefinition, 'item to echo',
                 node, 'item to echo'
             )
+            node.name('echo %s' % index)
 
         return compositeDefinition
 
@@ -329,6 +340,7 @@ class TestCase9(BaseTestClass, unittest.TestCase):
                 compositeDefinition, 'item to echo',
                 node, 'item to echo'
             )
+            node.name('echo %s' % index)
             nodes.append(node)
             pass
 
@@ -375,7 +387,8 @@ class TestCase10(BaseTestClass, unittest.TestCase):
         
         node = compositeDefinition.createNode(id='node')
         node.definitionToReference(atomicDefinition)
-        
+        node.name('echo')
+
         return compositeDefinition
 
 
@@ -412,7 +425,7 @@ class TestParameterSweep1(BaseTestClass, unittest.TestCase):
         compositeDefinition = DefinitionModule.getNewNestDefinition()
         node = compositeDefinition.createNode(id='node')
         node.definitionToReference(atomicDefinition)
-
+        node.name('echo')
         
         parameter = ParameterModule.DataParameter(
             id='item to echo', 
@@ -1107,6 +1120,50 @@ class TestBranch1(BaseTestClass, unittest.TestCase):
     pass
 
 
+class TestCase11(TestCase1):
+    """
+    execute of atomic function
+    """
+
+    def getNumWorkersToInstantiate(self):
+        return 0
+
+    
+    def executeTask(self, task, 
+                    executeEnvironment=None):
+
+        automaton = self.automaton
+        successCallback = automaton.getPostExecuteCallbackFor(task)
+        errorCallback = automaton.getErrorCallbackFor(task)
+        executeTaskFunction = automaton.getExecuteTaskFunction(task)
+        
+        requestContext = self.getRequestContext(
+            task=task, executeEnvironment=executeEnvironment
+        )
+        request = threadpool.WorkRequest(
+            executeTaskFunction,
+            args = [],
+            kwds = requestContext,
+            callback = successCallback,
+            exc_callback = errorCallback
+        )
+
+        try:
+            automaton.enqueueRequest(request)
+            assert False
+        except ErrorModule.ExecutionError, e:
+            self.assertEquals('need to start thread before execution',
+                              str(e))
+
+        return request
+
+
+
+    # END TestCase11
+    pass
+
+
+
 def main():
     
     util.configLogging()
